import request from '@/utils/request'

// 查询列表
export function findInformationList(data) {
  return request({
    url: '/enterprise/information/findInformationList',
    method: 'post',
    data
  })
}

// 新增
export function insertInformation(data) {
  return request({
    url: '/enterprise/information/insertInformation',
    method: 'post',
    data
  })
}

// 修改
export function updateInformationById(data) {
  return request({
    url: '/enterprise/carmsg/updateInformationById',
    method: 'post',
    data
  })
}

// 删除
export function deleteInformationById(id) {
  return request({
    url: '/enterprise/information/deleteInformationById?id='+id,
    method: 'post'
  })
}

// 根据ID查询信息
export function findInformationByid(id) {
  return request({
    url: '/enterprise/carmsg/findInformationByid?id='+id,
    method: 'post'
  })
}
// 根据ID查询信息
export function gaiZhuangTai(id) {
  return request({
    url: '/enterprise/information/findInformationByid?id='+id,
    method: 'post'
  })
}
export function updCarStrategyId(carId,strategyId) {
  return request({
    url: '/enterprise/information/updCarStrategyId',
    method: 'post',
    params:{carId:carId,strategyId:strategyId}
  })
}
